/*
 * This file is part of Alida, a Java library for 
 * Automatic Logging of Process Information in Data Analysis.
 *
 * Copyright (C) 2010 - 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on Alida, visit
 *
 *    http://www.informatik.uni-halle.de/alida/
 *
 */

/*
 * Most recent change(s):
 *
 * $Rev$
 * $Date$
 * $Author$
 *
 */
package de.unihalle.informatik.Alida.demo;

import de.unihalle.informatik.Alida.exceptions.ALDOperatorException;
import de.unihalle.informatik.Alida.operator.ALDOperator;
import de.unihalle.informatik.Alida.operator.Parameter;

/**
 * Operator for calculating the mean of given double values.
 * 
 * @author moeller
 */
public class ALDCalcMean extends ALDOperator {

  /**
   * Input data array.
   */
  @Parameter( label= "Input data", required = true, 
  		type = Parameter.Type.INPUT, description = "Input data.")
  private Double [] data;

  /**
   * Calculated average value.
   */
  @Parameter( label= "Mean value",  
  		type = Parameter.Type.OUTPUT, description = "Result.")
  private Double mean = null;

	/**
	 * Constructor.
	 * 
	 * @param _data	Input data.
	 * @throws ALDOperatorException
	 */
	protected ALDCalcMean(Double [] _data) throws ALDOperatorException {
		super();
		this.data = _data;
	}

	@Override
	protected void operate() {
		// calculate the mean of the data
		double tmpMean = 0.0;
		for (int i=0; i<this.data.length; ++i) {
			tmpMean += this.data[i].doubleValue();
		}
		this.mean = new Double(tmpMean/this.data.length);
	}
	
	/**
	 * Returns the calculated mean value.
	 */
	public Double getResultMean() {
		return this.mean;
	}
}
