/*
 * This file is part of Alida, a Java library for 
 * Automatic Logging of Process Information in Data Analysis.
 *
 * Copyright (C) 2010 - 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on Alida, visit
 *
 *    http://www.informatik.uni-halle.de/alida/
 *
 */

/*
 * Most recent change(s):
 *
 * $Rev$
 * $Date$
 * $Author$
 *
 */

package de.unihalle.informatik.Alida.demo;

import de.unihalle.informatik.Alida.exceptions.ALDOperatorException;
import de.unihalle.informatik.Alida.operator.ALDOperator;
import de.unihalle.informatik.Alida.operator.Parameter;

/**
 * Operator to calculate data variance.
 * <p>
 * Given a set of values and their mean, the data variance is calculated.
 * 
 * @author moeller
 */
public class ALDCalcVar extends ALDOperator {

  /**
   * Input data values.
   */
  @Parameter( label= "Input data", required = true, 
  		type = Parameter.Type.INPUT, description = "Input data.")
  private Double [] data;

  /**
   * Mean of the input data.
   */
  @Parameter( label= "Mean value", required = true, 
  		type = Parameter.Type.INPUT, description = "Mean value.")
  private Double mean;

  /**
   * Calculated data variance.
   */
  @Parameter( label= "Variance value",  
  		type = Parameter.Type.OUTPUT, description = "Result.")
  private Double var = null;

  /**
   * Constructor.
   * 
   * @param _data		Input data values.
   * @param _mean		Mean value of input data.
   * @throws ALDOperatorException
   */
  protected ALDCalcVar(Double [] _data, Double _mean) 
  throws ALDOperatorException {
		super();
		this.data = _data;
		this.mean = _mean;
	}
  
	@Override
	protected void operate() {
		// calculate the data variance
		double tmpVar = 0.0;
		for (int i=0; i<this.data.length; ++i) {
			tmpVar += 
				 (this.data[i].doubleValue()-this.mean.doubleValue())
				*(this.data[i].doubleValue()-this.mean.doubleValue());
		}
		this.var = new Double(tmpVar/this.data.length);
	}
	
	/**
	 * Returns calculated variance.
	 */
	public Double getResultVar() {
		return this.var;
	}
}
