/*
 * This file is part of Alida, a Java library for 
 * Automatic Logging of Process Information in Data Analysis.
 *
 * Copyright (C) 2010 - 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on Alida, visit
 *
 *    http://www.informatik.uni-halle.de/alida/
 *
 */

/*
 * Most recent change(s):
 *
 * $Rev: 3733 $
 * $Date: 2011-04-28 17:49:42 +0200 (Do, 28 Apr 2011) $
 * $Author: moeller $
 *
 */

package de.unihalle.informatik.Alida.demo;

import de.unihalle.informatik.Alida.exceptions.ALDOperatorException;
import de.unihalle.informatik.Alida.exceptions.ALDProcessingDAGException;
import de.unihalle.informatik.Alida.operator.ALDOperator;

/**
 * Main demo class for demonstrating implementation and use of Alida operators.
 * 
 * @author moeller
 */
public class ALDDemo {

	/**
	 * Main routine making use of {@link ALDStatOp} operator.
	 */
	public static void main(String [] args) {

		try {
			// generate some data
			Double [] data = new Double[]{new Double(1.0), new Double(2.0),
					new Double(3.0), new Double(4.0), new Double(5.0)};

			// instantiate the operator for statistical calculations
			ALDStatOp mathDemo = new ALDStatOp(data);
			
			// run the operator...
			mathDemo.runOp(false);
			
			// ... and get its results
			Double meanRes = mathDemo.getMean();
			Double varRes = mathDemo.getVar();
			
			// save the processing histories for the result values
			ALDOperator.writeHistory(meanRes, "/tmp/mean");
			ALDOperator.writeHistory(varRes, "/tmp/var");
		} catch (ALDOperatorException e) {
			e.printStackTrace();
		} catch (ALDProcessingDAGException e) {
			e.printStackTrace();
		}
		
	}
}
