/*
 * This file is part of Alida, a Java library for 
 * Automatic Logging of Process Information in Data Analysis.
 *
 * Copyright (C) 2010 - 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on Alida, visit
 *
 *    http://www.informatik.uni-halle.de/alida/
 *
 */

/*
 * Most recent change(s):
 *
 * $Rev$
 * $Date$
 * $Author$
 *
 */

package de.unihalle.informatik.Alida.demo;

import de.unihalle.informatik.Alida.exceptions.ALDOperatorException;
import de.unihalle.informatik.Alida.exceptions.ALDProcessingDAGException;
import de.unihalle.informatik.Alida.operator.ALDOperator;
import de.unihalle.informatik.Alida.operator.Parameter;

/**
 * Operator for doing statistical calculations.
 * <p>
 * For a given set of double input values their mean and variance are 
 * calculated.
 * 
 * @author moeller
 */
public class ALDStatOp extends ALDOperator {

  /**
   * Input data array.
   */
  @Parameter( label= "Input data", required = true, 
  		type = Parameter.Type.INPUT, description = "Input data.")
  private Double [] data;

  /**
   * Calculated mean value of input data.
   */
  @Parameter( label= "Mean value",  
  		type = Parameter.Type.OUTPUT, description = "Result mean.")
  private Double mean = null;

  /**
   * Calculated variance value of input data.
   */
  @Parameter( label= "Var value",  
  		type = Parameter.Type.OUTPUT, description = "Result variance.")
  private Double var = null;

  /**
   * Constructor.
   * 
   * @param _data		Input data.
   * @throws ALDOperatorException
   */
  protected ALDStatOp(Double [] _data) throws ALDOperatorException {
		super();
		this.data = _data;
	}

	/**
	 * Returns calculated average value.
	 */
	public Double getMean() {
		return this.mean;
	}
	
	/**
	 * Returns calculated variance.
	 */
	public Double getVar() {
		return this.var;
	}

	@Override
	protected void operate()  {

		try {	
			// use a sub-operator to calculate the mean of the input data
			ALDCalcMean meanOp = new ALDCalcMean(this.data);
			meanOp.runOp(false);
			Double m = meanOp.getResultMean();
			this.mean = m;
			
			// pass mean to another operator to calculate variance
			ALDCalcVar varOp = new ALDCalcVar(this.data, this.mean);
			varOp.runOp(false);
			Double v = varOp.getResultVar();
			this.var = v;
			
		} catch (ALDOperatorException e) {
			e.printStackTrace();
		} 
		catch (ALDProcessingDAGException e) {
			e.printStackTrace();
		}
	}
}
