/*
 * This file is part of Alida, a Java library for 
 * Automatic Logging of Process Information in Data Analysis.
 *
 * Copyright (C) 2010 - 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on Alida, visit
 *
 *    http://www.informatik.uni-halle.de/alida/
 *
 */

/* 
 * Most recent change(s):
 * 
 * $Rev: 3765 $
 * $Date: 2011-05-05 10:31:24 +0200 (Do, 05 Mai 2011) $
 * $Author: moeller $
 * 
 */

package de.unihalle.informatik.Alida.tools;

import de.unihalle.informatik.Alida.operator.*;

/**
 * Generates code for getter/setter methods for an ALDOperator.
 * <p>
 * This tool is mostly helpful for non-eclipse users who need to explicitly
 * code getters and setters for their operators. Note, that the tool assumes 
 * that names/labels of variables are identical to the name of the member/field. 
 * 
 * @author posch
 */
public class GenerateGetterSetter {

	/**
	 * Main function.
	 * 
	 * @param args	Name of class to document.
	 */
	public static void main(String [] args) {
		System.out.print(" " +
				"<Alida>  Copyright (C) 2010-2011  \n" +
				"This program comes with ABSOLUTELY NO WARRANTY; \n" +
				"This is free software, and you are welcome to redistribute it\n" +
				"under the terms of the GNU General Public License.\n\n\n");
		
		if ( args.length != 1 ) {
			System.err.println( "usage: GenerateGetterSetter classname");
			System.exit(-1);
		}

		ALDOperator op = null;
		try {
			System.out.println( Class.forName( args[0]));
			System.out.println();

			op = (ALDOperator)(Class.forName( args[0]).newInstance());
		} catch (Exception e) {
			System.err.println( "GenerateGetterSetter: cannot instantiate "+args[0]);
			e.printStackTrace();
		}


		try {
	    	String[] parameterNames = op.getParameterNames();
        	for ( int n=0 ; n < op.getNumParameters() ; n++ )
            	System.out.println( generateAccessFunction( op.getParameterDescriptor( parameterNames[n]), "Parameter"));

	    	String[] inputNames = op.getInputNames();
        	for ( int n=0 ; n < op.getNumInputs() ; n++ )
            	System.out.println( generateAccessFunction( op.getInputDescriptor( inputNames[n]), "Input"));

	    	String[] outputNames = op.getOutputNames();
        	for ( int n=0 ; n < op.getNumOutputs() ; n++ )
            	System.out.println( generateAccessFunction( op.getOutputDescriptor( outputNames[n]), "Output"));

	    	String[] supplementalNames = op.getSupplementalNames();
        	for ( int n=0 ; n < op.getNumSupplementals() ; n++ )
				if ( ! supplementalNames[n].equals( "verbose") ) 
            		System.out.println( generateAccessFunction( op.getSupplementalDescriptor( supplementalNames[n]), "Supplemental"));
		} catch (Exception e) {
			System.err.println( "GenerateGetterSetter: got excpetion");
			e.printStackTrace();
		}

	}

	/**
	 * Generate access function code.
	 * 
	 * @param descriptor	Argument descriptor.
	 * @param argType			Type of the argument.
	 * @return
	 */
	private static String generateAccessFunction( 
			ALDOpArgumentDescriptor descriptor,	String argType) {
		return new String(  "\t/** Get value of " + descriptor.name + ".\n" +
							"\t  * Explanation: " + descriptor.explanation + ".\n" +
							"\t  * @return value of " + descriptor.name + "\n" +
							"\t  */\n" +
							"\tpublic " + descriptor.myclass.getName() +
							" get" + Character.toUpperCase( descriptor.name.charAt(0)) +
                            descriptor.name.substring(1) + "(){\n" +
							"\t\treturn " + descriptor.name + ";\n" +
							"\t}\n" +

							"\n" + 

							"\t/** Set value of " + descriptor.name + ".\n" +
							"\t  * Explanation: " + descriptor.explanation + ".\n" +
							"\t  * @param value New value of " + descriptor.name + "\n" +
							"\t  */\n" +
							"\tpublic void " + 
							"set" + Character.toUpperCase( descriptor.name.charAt(0)) +
                            descriptor.name.substring(1) + "( " + descriptor.myclass.getName() + " value){\n" +
							"\t\tthis." + descriptor.name + " = value;\n" +
							"\t}\n" 

					);
	}

	/**
	 * @param descriptor
	 * @param argType
	 * @return
	 * 
	 * @deprecated
	 */
	@Deprecated
	private static String generateAccessFunctionNoAnnotation(
			ALDOpArgumentDescriptor descriptor, String argType) {
		return new String(  "/** Get value of " + argType + " argument " + descriptor.name + ".\n" +
							"  * @return value of " + descriptor.name + "\n" +
							"  */\n" +
							"public " + descriptor.myclass.getName() +
							" get" + Character.toUpperCase( descriptor.name.charAt(0)) + 
							descriptor.name.substring(1) +
							"()" + " throws ALDOperatorException {\n\treturn (" + descriptor.myclass.getName() + ")" +
							"(this.get" + argType + "(\"" +descriptor.name + "\"));\n}\n" +

							"/** Set value of " + argType + " argument " + descriptor.name + ".\n" +
							"  * @param value New value for " + descriptor.name + "\n" +
							"  */\n" +
							"public void" +
							" set" + Character.toUpperCase( descriptor.name.charAt(0)) + 
							descriptor.name.substring(1) +
							"( " + descriptor.myclass.getName() + " value )" + 
							" throws ALDOperatorException {\n\t" + 
							" this.set" + argType + "(\"" +descriptor.name + "\", value);\n}\n" 
					);
	}

}
